#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-8WmFreG7uAGEE12Y1qOxCF
key:                  svg-builder-0.1.1-8WmFreG7uAGEE12Y1qOxCF
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  e037c2645d0b25be2af9b502fe5d27f3
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-8.10.5/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/svg-builder-0.1.1
hs-libraries:         HSsvg-builder-0.1.1-8WmFreG7uAGEE12Y1qOxCF
depends:
    base-4.14.2.0 blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB
    bytestring-0.10.12.0 hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    text-1.2.4.1 unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

